Struct ZwlrGammaControlV1
pub struct ZwlrGammaControlV1 { /* private fields */ }wayland and Linux only.Expand description
adjust gamma tables for an output
This interface allows a client to adjust gamma tables for a particular output.
The client will receive the gamma size, and will then be able to set gamma tables. At any time the compositor can send a failed event indicating that this object is no longer valid.
There can only be at most one gamma control object per output, which has exclusive access to this particular output. When the gamma control object is destroyed, the gamma table is restored to its original value.
See also the Request enum for this interface.
Implementations
impl ZwlrGammaControlV1
impl ZwlrGammaControlV1
pub fn gamma_size(&self, size: u32)
pub fn gamma_size(&self, size: u32)
size of gamma ramps
Advertise the size of each gamma ramp.
This event is sent immediately when the gamma control object is created.
pub fn failed(&self)
pub fn failed(&self)
object no longer valid
This event indicates that the gamma control is no longer valid. This can happen for a number of reasons, including:
- The output doesn’t support gamma tables
- Setting the gamma tables failed
- Another client already has exclusive gamma control for this output
- The compositor has transferred gamma control to another client
Upon receiving this event, the client should destroy this object.